@@ -15,7 +15,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.717';
+our $VERSION = '2017.718';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -663,9 +663,7 @@ sub extractDocumentation()
      }
     elsif ($level and $L =~ /\A\s*sub\s*(.+?)\s*#\s*(.+?)\s*\Z/)                # Documentation for a method = sub name comment
      {my ($n, $d) = ($1, $2);                                                   # Name from sub, description from comment
-say STDERR "AAAA =", dump($n, $d);
       next if $d =~ /\A#/;                                                      # Private method if ##
-say STDERR "BBBB ";
       my $signature = $n =~ s/\A\s*\w+//gsr =~                                  # Signature
                             s/\A\(//gsr     =~
                             s/\)\s*(:lvalue\s*)?\Z//gsr =~
